@@ -16,7 +16,7 @@ from loguru import logger
 from requests.adapters import HTTPAdapter, PoolManager
 from urllib3.util.ssl_ import create_urllib3_context
 
-from .lib import ensure_file, tqdm_loguru
+from .lib import log_error, mkdir, tqdm_loguru
 
 
 def handle_exception(func):
@@ -84,7 +84,7 @@ def write_content(
     if path.exists():
         logger.debug(f"文件已存在: {path}")
         return
-    ensure_file(path)
+    mkdir(path.parent).lash(lambda err: log_error("文件夹创建失败", err))
     while (
         content := get_content(
             url=url, session=session, proxies=proxies, headers=headers
@@ -126,13 +126,13 @@ def get_task_info(
     token: str,
     domain: str,
     session: requests.Session | None = None,
-    host: str | None = None,
+    headers: dict[str, str] | None = None,
 ):
     """请求task_info信息"""
     url = f"{domain}/api/v2/task/get/task-info"
-    headers = __get_headers(token)
-    if host:
-        headers["Host"] = host
+    if not headers:
+        headers = {}
+    headers.update(__get_headers(token))
     params = {"taskId": task_id}
     response = (session or requests).post(url, headers=headers, json=params)
     response.raise_for_status()
