@@ -7,13 +7,15 @@
 """
 
 import base64
+from bisect import bisect_left
 import datetime
 import hashlib
 import json
+from re import L
 import sys
 import uuid
 from pathlib import Path, PurePath
-from typing import Callable, Iterable, TextIO, TypeVar
+from typing import Any, Callable, Generator, Iterable, Sequence, TextIO, Tuple, TypeVar
 from urllib.parse import unquote, urlparse
 
 from tqdm import tqdm
@@ -24,13 +26,6 @@ from loguru._logger import Logger as LoguruLogger
 from returns.io import IO, impure_safe
 
 
-def replace_suffix(file_name: str, suffix: str) -> str:
-    """替换后缀"""
-    parts = file_name.rsplit(".", maxsplit=1)
-    stem_idx = 0
-    return parts[stem_idx] + suffix
-
-
 @impure_safe
 def mkdir(path: Path) -> None:
     """创建目录"""
@@ -254,28 +249,19 @@ def get_timestamp() -> str:
     return time.strftime("%Y.%m.%d-%H:%M:%S.%f")
 
 
-def search_file_with_suffix(path: Path, suffixes: list[str]) -> list[Path]:
+def search_with_suffix(path: Path, suffixes: set[str]) -> Generator[Path, None, None]:
     """递归查找目录后缀文件"""
-    return [f for f in path.rglob(r"*") if f.suffix in suffixes]
+    for f in path.rglob(r"*"):
+        if f.suffix not in suffixes:
+            continue
+        yield f
 
 
-def cut_url(
-    url: str, start_level: int = 2, end_level: int = -1, with_file_name: bool = False
-) -> PurePath:
-    """切割url"""
-    url_parse = urlparse(url)
-    url_path = url_parse.path
-    unquoted_url_path = Path(unquote(url_path))
-    if with_file_name:
-        end_level = len(unquoted_url_path.parts)
-    return PurePath(*unquoted_url_path.parts[start_level:end_level])
-
-
-def extract_url_path(url: str) -> PurePath:
-    """提取url路径"""
-    url_parse = urlparse(url)
-    path = unquote(url_parse.path)
-    return PurePath(path)
+def url_to_path(url: str) -> Path:
+    """url转换为路径"""
+    url_parsed = urlparse(url)
+    unquote_path = unquote(url_parsed.path)
+    return Path(unquote_path)
 
 
 def recursive_replace(s: str, replace_map: dict[str, str]) -> str:
@@ -312,3 +298,24 @@ def sort_dict(data: dict, sort_rule: Callable[any, int]) -> dict:
     排序字典
     """
     return dict(sorted(data.items(), key=lambda x: sort_rule(x)))
+
+
+def find_nearest(sorted_seq: Sequence, target: Any) -> Tuple[Any, int]:
+    """
+    有序列中最近 target 元素
+
+    :param sorted_seq: 已排序的序列 (必须支持索引操作)
+    :param target: 待查询的值
+    :return: (最接近的元素, 该元素的索引)
+    """
+    pos = bisect_left(sorted_seq, target)
+
+    if pos == 0:
+        return sorted_seq[0], 0
+    if pos == len(sorted_seq):
+        return sorted_seq[-1], len(sorted_seq) - 1
+
+    before, after = sorted_seq[pos - 1], sorted_seq[pos]
+    nearest = after if after - target < target - before else before
+    idx = pos if nearest == after else pos - 1
+    return nearest, idx
